From 21b422887cf8aeb44289731f0e8532f9b42e72e7 Mon Sep 17 00:00:00 2001
From: Steffen Vogel <post@steffenvogel.de>
Date: Fri, 1 May 2015 18:57:55 +0200
Subject: [PATCH] Fix: allow pass to be a symlink to the real password-store.sh

Using symlinks has broken the inclusing of platform specific options
like the OS X clipbord support.
We need to recursively resolve the variable BASH_SOURCE to solve this
issue.
---
 src/password-store.sh | 16 +++++++++++++++-
 1 file changed, 15 insertions(+), 1 deletion(-)

diff --git a/src/password-store.sh b/src/password-store.sh
index 47f7ffa..9eeb7e5 100755
--- a/src/password-store.sh
+++ b/src/password-store.sh
@@ -20,6 +20,20 @@ export GIT_DIR="${PASSWORD_STORE_GIT:-$PREFIX}/.git"
 export GIT_WORK_TREE="${PASSWORD_STORE_GIT:-$PREFIX}"
 
 #
+# Get real location of pass
+#
+
+SOURCE="${BASH_SOURCE[0]}"
+# resolve $SOURCE until the file is no longer a symlink
+while [ -h "$SOURCE" ]; do
+	PASS_DIR="$( cd -P "$( dirname "$SOURCE" )" && pwd )"
+	SOURCE="$(readlink "$SOURCE")"
+	# if $SOURCE was a relative symlink, we need to resolve it relative to the path where the symlink file was located
+	[[ $SOURCE != /* ]] && SOURCE="$PASS_DIR/$SOURCE"
+done
+PASS_DIR="$( cd -P "$( dirname "$SOURCE" )" && pwd )"
+
+#
 # BEGIN helper functions
 #
 
@@ -185,7 +199,7 @@ tmpdir() {
 GETOPT="getopt"
 SHRED="shred -f -z"
 
-source "$(dirname "$0")/platform/$(uname | cut -d _ -f 1 | tr '[:upper:]' '[:lower:]').sh" 2>/dev/null # PLATFORM_FUNCTION_FILE
+source "$PASS_DIR/platform/$(uname | cut -d _ -f 1 | tr '[:upper:]' '[:lower:]').sh" 2>/dev/null # PLATFORM_FUNCTION_FILE
 
 #
 # END platform definable
-- 
2.3.0

